// ---------------------------------------------------------------------------
// Copyright:   (c) 2021 ff. Michael Amrhein (michael@adrhinum.de)
// License:     This program is part of a larger application. For license
//              details please read the file LICENSE.TXT provided together
//              with the application.
// ---------------------------------------------------------------------------
// $Source: src/prelude.rs $
// $Revision: 2022-02-10T18:40:51+01:00 $

//! This module reexports all macros and types needed to define a quantity.

pub use crate::{Amnt, AmountT, HasRefUnit, Quantity, SIPrefix, Unit, ONE};
#[cfg(feature = "fpdec")]
pub use crate::{Dec, Decimal};
pub use core::cmp::Ordering;
pub use core::fmt;
pub use core::ops::{Add, Div, Mul, Sub};
pub use qty_macros::quantity;
